@@ -1,3 +1,3 @@
-from .pylake import (thermocline, seasonal_thermocline, metalimnion, mixed_layer,
+from .pylake import (thermocline, metalimnion, mixed_layer,
      wedderburn, schmidt_stability,seiche_period_1, internal_energy, 
      Lake_number, buoyancy_freq, Average_layer_temp)
